@@ -25,10 +25,11 @@ public:
         UoidRole,
         IdentityNameRole,
         DisplayNameRole,
+        DefaultRole,
     };
 
-    IdentityModel(QObject *parent = nullptr);
-    ~IdentityModel();
+    explicit IdentityModel(QObject *parent = nullptr);
+    ~IdentityModel() override;
 
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
@@ -40,10 +41,8 @@ public:
      */
     Q_INVOKABLE QString email(uint uoid);
 
-private Q_SLOTS:
-    void reloadUoidList();
-
 private:
+    KIDENTITYMANAGEMENTCORE_NO_EXPORT void reloadUoidList();
     QList<int> m_identitiesUoid;
     IdentityManager *const m_identityManager;
 };
